package com.muyu.pay.common.domain.resp;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.pay.common.domain.OrderPayCustomer;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;
import java.util.function.Function;
import java.util.function.Supplier;

@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Tag(name = "客户信息响应对象",description = "负责客户信息查询的响应结果")
public class CustomerResp {

    @Schema(description = "客户ID",defaultValue = "1",type = "Long")
    private Long id;

    /**
     * 服务/客户名称
     */
    @Schema(description = "客户名称",defaultValue = "商品服务",type = "String")
    private String appName;

    /**
     * 服务/客户编码
     */
    @Schema(description = "客户编号",defaultValue = "cloud_order",type = "String")
    private String appCode;

    /**
     * 客户描述
     */
    @Schema(description = "客户描述",defaultValue = "------",type = "String")
    private String appDesc;

    /**
     * 状态
     */
    @Schema(description = "客户状态:同数据字典",defaultValue = "Y",type = "String")
    private String status;


    @Schema(description = "创建人",defaultValue = "大壮",type = "String")
    private String createBy;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间",defaultValue = "2024-7-31 21:16:45",type = "Date")
    private Date createTime;

    /**
     * 客户最近5条支付单
     */
    @Schema(description = "客户最近5条支付单")
    private List<CustomerOrderPaySimpleResp> orderPaySimpleRespsList;


    public static CustomerResp customerBuild(OrderPayCustomer orderPayCustomer, Supplier<List<CustomerOrderPaySimpleResp>> function){

        return CustomerResp.builder()
                .id(orderPayCustomer.getId())
                .appName(orderPayCustomer.getAppCode())
                .appCode(orderPayCustomer.getAppCode())
                .appDesc(orderPayCustomer.getAppDesc())
                .status(orderPayCustomer.getStatus())
                .createBy(orderPayCustomer.getCreateBy())
                .createTime(orderPayCustomer.getCreateTime())
                .orderPaySimpleRespsList(function.get())
                .build();
    }


}
