package com.muyu.pay.server.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.pay.common.domain.OrderPayCustomer;
import com.muyu.pay.common.domain.req.CustomerListReq;
import com.muyu.pay.common.domain.resp.CustomerResp;
import com.muyu.pay.server.service.OrderPayCustomerService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;


import java.util.List;

@Log4j2
@RestController
@RequestMapping("customer")
@RequiredArgsConstructor
@Tag(name = "客户控制层", description = "进行客户管理查询操作")
public class OrderPayCustomerController {

    private final OrderPayCustomerService orderPayCustomerService;

    @PostMapping("/list")
    @Operation(summary = "查看客户", description = "根据客户名称 编号 状态 查询")
    public Result<List<CustomerResp>> selectList(
            @Validated @RequestBody CustomerListReq req) {
        return Result.success(orderPayCustomerService.selectList(req));
    }

    /**
     * 获取所以客户
     *
     * @return
     */
    @GetMapping("all")
    @Operation(summary = "获取未接入客户",description = "调用nacosAPI")
    @Schema(description = "获取未接入客户",type = "List")
    public Result<List<String>> getCustomerAllList() {
        return Result.success(
                orderPayCustomerService.getCustomerAllList()
        );
    }


}
