package com.muyu.pay.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.enums.SysPayType;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.nacos.service.NacosServerService;
import com.muyu.pay.common.domain.OrderPayCustomer;
import com.muyu.pay.common.domain.OrderPayInfo;
import com.muyu.pay.common.domain.req.CustomerListReq;
import com.muyu.pay.common.domain.resp.CustomerOrderPaySimpleResp;
import com.muyu.pay.common.domain.resp.CustomerResp;
import com.muyu.pay.server.mapper.OrderPayCustomerMapper;
import com.muyu.pay.server.service.OrderPayCustomerService;
import com.muyu.pay.server.service.OrderPayInfoService;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

@Log4j2
@Service
public class OrderPayCustomerServiceImpl
        extends ServiceImpl<OrderPayCustomerMapper, OrderPayCustomer>
        implements OrderPayCustomerService {


    @Resource
    private OrderPayInfoService orderPayInfoService;

    @Resource
    private NacosServerService nacosServerService;


    @Override
    public List<CustomerResp> selectList(CustomerListReq req) {
        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(
                StringUtils.isNotEmpty(req.getAppName()),
                OrderPayCustomer::getAppName,
                req.getAppName()
        );
        queryWrapper.like(
                StringUtils.isNotEmpty(req.getAppCode()),
                OrderPayCustomer::getAppCode,
                req.getAppCode()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(req.getStatus()),
                OrderPayCustomer::getStatus,
                req.getStatus()
        );

        List<OrderPayCustomer> orderPayCustomerList = this.list(queryWrapper);
        return orderPayCustomerList.stream()
                .map(orderPayCustomer -> CustomerResp.customerBuild(orderPayCustomer, () ->
                        orderPayInfoService.selectOrderPayByAppCodeAndLimit(orderPayCustomer.getAppCode(), 5)
                                .stream()
                                .map(OrderPayInfo::buildCustomerOrderPaySimpleResp)
                                .toList()
                ))
                .toList();

    }

    @Override
    public List<String> getCustomerAllList() {
        List<String> nacosServerAllList = nacosServerService.nacosServerAllList();
        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.select(OrderPayCustomer::getAppCode);
        List<OrderPayCustomer> list = this.list(queryWrapper);
        Set<String> customerSet = list.stream().map(OrderPayCustomer::getAppCode).collect(Collectors.toSet());
        return nacosServerAllList.stream()
                .filter(nacosServer->!customerSet.contains(nacosServer))
                .toList();
    }
}
